@@ -4,13 +4,15 @@
  * SPDX-License-Identifier: LGPL-2.1+
  */
 
-#define HANDY_USE_UNSTABLE_API
 #include <handy.h>
 
+#define TEST_ICON_NAME "avatar-default-symbolic"
 #define TEST_STRING "Mario Rossi"
 #define TEST_SIZE 128
 
 
+gint load_image_func_count;
+
 static gboolean
 is_surface_empty (cairo_surface_t *surface)
 {
@@ -32,6 +34,7 @@ static GdkPixbuf *
 load_null_image_func (gint size,
                       gpointer data)
 {
+  load_image_func_count++;
   return NULL;
 }
 
@@ -43,6 +46,8 @@ load_image_func (gint size,
   cairo_surface_t *surface;
   cairo_t *cr;
 
+  load_image_func_count++;
+
   surface = cairo_image_surface_create (CAIRO_FORMAT_ARGB32, size, size);
   cr = cairo_create (surface);
   if (color != NULL) {
@@ -113,6 +118,18 @@ test_hdy_avatar_generate (void)
 }
 
 
+static void
+test_hdy_avatar_icon_name (void)
+{
+  HdyAvatar *avatar = HDY_AVATAR (hdy_avatar_new (128, NULL, TRUE));
+
+  g_assert_null (hdy_avatar_get_icon_name (avatar));
+  hdy_avatar_set_icon_name (avatar, TEST_ICON_NAME);
+  g_assert_cmpstr (hdy_avatar_get_icon_name (avatar), ==, TEST_ICON_NAME);
+
+  g_assert_true (did_draw_something (GTK_WIDGET (avatar)));
+}
+
 static void
 test_hdy_avatar_text (void)
 {
@@ -147,6 +164,8 @@ test_hdy_avatar_custom_image (void)
 
   g_assert (HDY_IS_AVATAR (avatar));
 
+  load_image_func_count = 0;
+
   hdy_avatar_set_image_load_func (HDY_AVATAR (avatar),
                                   (HdyAvatarImageLoadFunc) load_image_func,
                                   NULL,
@@ -177,6 +196,8 @@ test_hdy_avatar_custom_image (void)
 
   g_assert_true (did_draw_something (avatar));
 
+  g_assert_cmpint (load_image_func_count, ==, 3);
+
   g_object_unref (avatar);
 }
 
@@ -190,6 +211,7 @@ main (gint argc,
 
   g_test_add_func ("/Handy/Avatar/generate", test_hdy_avatar_generate);
   g_test_add_func ("/Handy/Avatar/custom_image", test_hdy_avatar_custom_image);
+  g_test_add_func ("/Handy/Avatar/icon_name", test_hdy_avatar_icon_name);
   g_test_add_func ("/Handy/Avatar/text", test_hdy_avatar_text);
   g_test_add_func ("/Handy/Avatar/size", test_hdy_avatar_size);
 
